'''
Commands to manage databricks workspace.
'''
from ... pyaz_utils import _call_az
from . import vnet_peering


def create(location, name, resource_group, sku, enable_no_public_ip=None, managed_resource_group=None, no_wait=None, prepare_encryption=None, private_subnet=None, public_subnet=None, require_infrastructure_encryption=None, tags=None, vnet=None):
    '''
    Create a new workspace.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- The SKU tier name.

    Optional Parameters:
    - enable_no_public_ip -- Flag to enable the no public ip feature.
    - managed_resource_group -- The managed resource group to create. It can be either a name or a resource ID.
    - no_wait -- Do not wait for the long-running operation to finish.
    - prepare_encryption -- Flag to enable the Managed Identity for managed storage account to prepare for CMK encryption.
    - private_subnet -- The name of a Private Subnet within the Virtual Network.
    - public_subnet -- The name of a Public Subnet within the Virtual Network.
    - require_infrastructure_encryption -- Flag to enable the DBFS root file system with secondary layer of encryption with platform managed keys for data at rest.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet -- Virtual Network name or resource ID.
    '''
    return _call_az("az databricks workspace create", locals())


def update(name, resource_group, key_name=None, key_source=None, key_vault=None, key_version=None, no_wait=None, prepare_encryption=None, tags=None):
    '''
    Update the workspace.

    Required Parameters:
    - name -- The name of the workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - key_name -- The name of KeyVault key.
    - key_source -- The encryption key source (provider).
    - key_vault -- The Uri of KeyVault.
    - key_version -- The version of KeyVault key. It is optional when updating CMK.
    - no_wait -- Do not wait for the long-running operation to finish.
    - prepare_encryption -- Flag to enable the Managed Identity for managed storage account to prepare for CMK encryption.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az databricks workspace update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete the workspace.

    Required Parameters:
    - name -- The name of the workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az databricks workspace delete", locals())


def show(name, resource_group):
    '''
    Show the workspace.

    Required Parameters:
    - name -- The name of the workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databricks workspace show", locals())


def list(resource_group=None):
    '''
    Get all the workspaces.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databricks workspace list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the Databricks workspace is met.

    Required Parameters:
    - name -- The name of the workspace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az databricks workspace wait", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, server, end_ip_address=None, start_ip_address=None):
    '''
    Create a firewall rule.

    Required Parameters:
    - name -- The name of the firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - end_ip_address -- The end IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    - start_ip_address -- The start IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    '''
    return _call_az("az sql server firewall-rule create", locals())


def update(name, resource_group, server, end_ip_address=None, start_ip_address=None):
    '''
    Update a firewall rule.

    Required Parameters:
    - name -- The name of the firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - end_ip_address -- The end IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    - start_ip_address -- The start IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    '''
    return _call_az("az sql server firewall-rule update", locals())


def delete(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server firewall-rule delete", locals())


def show(name, resource_group, server):
    '''
    Shows the details for a firewall rule.

    Required Parameters:
    - name -- The name of the firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server firewall-rule show", locals())


def list(resource_group, server):
    '''
    List a server's firewall rules.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server firewall-rule list", locals())




from ... pyaz_utils import _call_az

def create(categories, days, enabled, location, locations, name, service_bus_rule_id=None, storage_account_id=None, tags=None):
    '''
    Create a log profile.

    Required Parameters:
    - categories -- None
    - days -- None
    - enabled -- None
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - locations -- None
    - name -- None

    Optional Parameters:
    - service_bus_rule_id -- None
    - storage_account_id -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor log-profiles create", locals())


def delete(name):
    '''
    

    Required Parameters:
    - name -- The name of the log profile.
    '''
    return _call_az("az monitor log-profiles delete", locals())


def show(name):
    '''
    

    Required Parameters:
    - name -- The name of the log profile.
    '''
    return _call_az("az monitor log-profiles show", locals())


def list():
    return _call_az("az monitor log-profiles list", locals())


def update(name, add=None, force_string=None, remove=None, set=None):
    '''
    Update a log profile.

    Required Parameters:
    - name -- The name of the log profile.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az monitor log-profiles update", locals())




'''
Manage keys for Azure SignalR Service.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List the access keys for a SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr key list", locals())


def renew(key_type, name, resource_group):
    '''
    Regenerate the access key for a SignalR Service.

    Required Parameters:
    - key_type -- The name of access key to regenerate
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr key renew", locals())




'''
Manage Azure Active Directory group owners.
'''
from .... pyaz_utils import _call_az

def list(group):
    '''
    List group owners.

    Required Parameters:
    - group -- group's object id or display name(prefix also works if there is a unique match)
    '''
    return _call_az("az ad group owner list", locals())


def add(group, owner_object_id):
    '''
    Add a group owner.

    Required Parameters:
    - group -- group's object id or display name(prefix also works if there is a unique match)
    - owner_object_id -- owner's object id
    '''
    return _call_az("az ad group owner add", locals())


def remove(group, owner_object_id):
    '''
    Remove a group owner.

    Required Parameters:
    - group -- group's object id or display name(prefix also works if there is a unique match)
    - owner_object_id -- owner's object id
    '''
    return _call_az("az ad group owner remove", locals())




from .... pyaz_utils import _call_az

def create(endpoint_name, name, private_dns_zone, resource_group, zone_name):
    '''
    Create a private endpoint dns zone group.

    Required Parameters:
    - endpoint_name -- Name of the private endpoint.
    - name -- Name of the private dns zone group.
    - private_dns_zone -- Name or ID of the private dns zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- Name of the private dns zone.
    '''
    return _call_az("az network private-endpoint dns-zone-group create", locals())


def add(endpoint_name, name, private_dns_zone, resource_group, zone_name):
    '''
    Add a private endpoint dns zone into a dns zone group.

    Required Parameters:
    - endpoint_name -- Name of the private endpoint.
    - name -- Name of the private dns zone group.
    - private_dns_zone -- Name or ID of the private dns zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- Name of the private dns zone.
    '''
    return _call_az("az network private-endpoint dns-zone-group add", locals())


def remove(endpoint_name, name, resource_group, zone_name):
    '''
    Remove a private endpoint dns zone into a dns zone group.

    Required Parameters:
    - endpoint_name -- Name of the private endpoint.
    - name -- Name of the private dns zone group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- Name of the private dns zone.
    '''
    return _call_az("az network private-endpoint dns-zone-group remove", locals())


def delete(endpoint_name, name, resource_group):
    '''
    Delete a private endpoint dns zone group.

    Required Parameters:
    - endpoint_name -- Name of the private endpoint.
    - name -- Name of the private dns zone group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-endpoint dns-zone-group delete", locals())


def show(endpoint_name, name, resource_group):
    '''
    Show a private endpoint dns zone group.

    Required Parameters:
    - endpoint_name -- Name of the private endpoint.
    - name -- Name of the private dns zone group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-endpoint dns-zone-group show", locals())


def list(endpoint_name, resource_group):
    '''
    List all private endpoint dns zone groups.

    Required Parameters:
    - endpoint_name -- Name of the private endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-endpoint dns-zone-group list", locals())




from ..... pyaz_utils import _call_az

def set(dh_group, ike_encryption, ike_integrity, ipsec_encryption, ipsec_integrity, name, pfs_group, resource_group, sa_lifetime, sa_max_size, no_wait=None):
    '''
    Set the VPN client connection ipsec policy per P2S client connection of the virtual network gateway.

    Required Parameters:
    - dh_group -- The DH Groups used for initial SA.
    - ike_encryption -- The IKE encryption algorithm.
    - ike_integrity -- The IKE integrity algorithm.
    - ipsec_encryption -- The IPSec encryption algorithm.
    - ipsec_integrity -- The IPSec integrity algorithm.
    - name -- Name of the VNet gateway.
    - pfs_group -- The Pfs Groups used for new child SA.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sa_lifetime -- The lifetime in seconds for P2S client.
    - sa_max_size -- The payload size in KB for P2S client.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vnet-gateway vpn-client ipsec-policy set", locals())


def show(name, resource_group):
    '''
    Get the VPN client connection ipsec policy per P2S client connection of the virtual network gateway.

    Required Parameters:
    - name -- Name of the VNet gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway vpn-client ipsec-policy show", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vnet gateway vpn client ipsec policy is met.

    Required Parameters:
    - name -- Name of the VNet gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network vnet-gateway vpn-client ipsec-policy wait", locals())




'''
See catalog of available reservations
'''
from ... pyaz_utils import _call_az

def show(reserved_resource_type, subscription_id, location=None):
    '''
    Get catalog of available reservation.

    Required Parameters:
    - reserved_resource_type -- The type of the resource for which the skus should be provided.
    - subscription_id -- Id of the subscription

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az reservations catalog show", locals())




'''
Manage user accounts for a VM.
'''
from ... pyaz_utils import _call_az

def update(name, resource_group, username, no_wait=None, password=None, ssh_key_value=None):
    '''
    Update a user account.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - username -- The user name

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - password -- The user password
    - ssh_key_value -- None
    '''
    return _call_az("az vm user update", locals())


def delete(name, resource_group, username, no_wait=None):
    '''
    Delete a user account from a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - username -- The user name

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm user delete", locals())


def reset_ssh(name, resource_group, no_wait=None):
    '''
    Reset the SSH configuration on a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm user reset-ssh", locals())




'''
Manage Azure Cosmos DB SQL containers.
'''
from .... pyaz_utils import _call_az
from . import throughput


def create(account_name, database_name, name, partition_key_path, resource_group, analytical_storage_ttl=None, conflict_resolution_policy=None, idx=None, max_throughput=None, partition_key_version=None, throughput=None, ttl=None, unique_key_policy=None):
    '''
    Create an SQL container under an Azure Cosmos DB SQL database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Container name
    - partition_key_path -- Partition Key Path, e.g., '/address/zipcode'
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_ttl -- Analytical TTL, when analytical storage is enabled.
    - conflict_resolution_policy -- Conflict Resolution Policy, you can enter it as a string or as a file, e.g., --conflict-resolution-policy @policy-file.json or --conflict-resolution-policy "{\"mode\": \"lastWriterWins\", \"conflictResolutionPath\": \"/path\"}"

    - idx -- Indexing Policy, you can enter it as a string or as a file, e.g., --idx @policy-file.json or --idx "{\"indexingMode\": \"consistent\", \"automatic\": true, \"includedPaths\": [{\"path\": \"/*\"}], \"excludedPaths\": [{ \"path\": \"/headquarters/employees/?\"}, { \"path\": \"/\\"_etag\\"/?\"}]}"

    - max_throughput -- The maximum throughput resource can scale to (RU/s). Provided when the resource is autoscale enabled. The minimum value can be 4000 (RU/s)
    - partition_key_version -- The version of partition key.
    - throughput -- The throughput of SQL container (RU/s). Default value is 400. Omit this parameter if the database has shared throughput unless the container should have dedicated throughput.
    - ttl -- Default TTL. If the value is missing or set to "-1", items don’t expire. If the value is set to "n", items will expire "n" seconds after last modified time.
    - unique_key_policy -- Unique Key Policy, you can enter it as a string or as a file, e.g., --unique-key-policy @policy-file.json or --unique-key-policy "{\"uniqueKeys\": [{\"paths\": [\"/path/to/key1\"]}, {\"paths\": [\"/path/to/key2\"]}]}"

    '''
    return _call_az("az cosmosdb sql container create", locals())


def update(account_name, database_name, name, resource_group, analytical_storage_ttl=None, idx=None, ttl=None):
    '''
    Update an SQL container under an Azure Cosmos DB SQL database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Container name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_ttl -- Analytical TTL, when analytical storage is enabled.
    - idx -- Indexing Policy, you can enter it as a string or as a file, e.g., --idx @policy-file.json or --idx "{\"indexingMode\": \"consistent\", \"automatic\": true, \"includedPaths\": [{\"path\": \"/*\"}], \"excludedPaths\": [{ \"path\": \"/headquarters/employees/?\"}, { \"path\": \"/\\"_etag\\"/?\"}]}"

    - ttl -- Default TTL. If the value is missing or set to "-1", items don’t expire. If the value is set to "n", items will expire "n" seconds after last modified time.
    '''
    return _call_az("az cosmosdb sql container update", locals())


def exists(account_name, database_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Container name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql container exists", locals())


def list(account_name, database_name, resource_group):
    '''
    List the SQL containers under an Azure Cosmos DB SQL database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql container list", locals())


def show(account_name, database_name, name, resource_group):
    '''
    Show the details of a SQL container under an Azure Cosmos DB SQL database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Container name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql container show", locals())


def delete(account_name, database_name, name, resource_group, yes=None):
    '''
    Delete the SQL container under an Azure Cosmos DB SQL database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Container name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb sql container delete", locals())




from ..... pyaz_utils import _call_az

def add(inbound_nat_rule, ip_config_name, nic_name, resource_group, lb_name=None):
    '''
    Add an inbound NAT rule to an IP configuration.

    Required Parameters:
    - inbound_nat_rule -- The name or ID of an existing inbound NAT rule.
    - ip_config_name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - lb_name -- The name of the load balancer associated with the NAT rule (Omit if suppying a NAT rule ID).
    '''
    return _call_az("az network nic ip-config inbound-nat-rule add", locals())


def remove(inbound_nat_rule, ip_config_name, nic_name, resource_group, lb_name=None):
    '''
    Remove an inbound NAT rule of an IP configuration.

    Required Parameters:
    - inbound_nat_rule -- The name or ID of an existing inbound NAT rule.
    - ip_config_name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - lb_name -- The name of the load balancer associated with the NAT rule (Omit if suppying a NAT rule ID).
    '''
    return _call_az("az network nic ip-config inbound-nat-rule remove", locals())




from ..... pyaz_utils import _call_az

def list():
    '''
    List ExpressRoute port locations.
    '''
    return _call_az("az network express-route port location list", locals())


def show(location):
    '''
    Get the details of an ExpressRoute port location.

    Required Parameters:
    - location -- Name of the requested ExpressRoutePort peering location.
    '''
    return _call_az("az network express-route port location show", locals())




'''
Manage Azure API Management API Version Set.
'''
from .... pyaz_utils import _call_az

def list(resource_group, service_name):
    '''
    Lists a collection of API Version Sets in the specified service instance.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim api versionset list", locals())


def show(resource_group, service_name, version_set_id):
    '''
    Gets the details of the Api Version Set specified by its identifier.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    - version_set_id -- A resource identifier for the related ApiVersionSet.
    '''
    return _call_az("az apim api versionset show", locals())


def create(display_name, resource_group, service_name, versioning_scheme, description=None, if_match=None, version_header_name=None, version_query_name=None, version_set_id=None):
    '''
    Creates a Api Version Set.

    Required Parameters:
    - display_name -- Required. Name of API Version Set
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    - versioning_scheme -- Required. An value that determines where the API Version identifer will be located in a HTTP request. Possible values include: 'Segment', 'Query', 'Header'

    Optional Parameters:
    - description -- Description of API Version Set.
    - if_match -- ETag of the Entity.
    - version_header_name -- Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
    - version_query_name -- Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
    - version_set_id -- A resource identifier for the related ApiVersionSet.
    '''
    return _call_az("az apim api versionset create", locals())


def update(resource_group, service_name, version_set_id, add=None, description=None, display_name=None, force_string=None, if_match=None, remove=None, set=None, version_header_name=None, version_query_name=None, versioning_scheme=None):
    '''
    Updates the details of the Api VersionSet specified by its identifier.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    - version_set_id -- A resource identifier for the related ApiVersionSet.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - description -- Description of API Version Set.
    - display_name -- Required. Name of API Version Set
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- ETag of the Entity.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - version_header_name -- Name of HTTP header parameter that indicates the API Version if versioningScheme is set to `header`.
    - version_query_name -- Name of query parameter that indicates the API Version if versioningScheme is set to `query`.
    - versioning_scheme -- Required. An value that determines where the API Version identifer will be located in a HTTP request. Possible values include: 'Segment', 'Query', 'Header'
    '''
    return _call_az("az apim api versionset update", locals())


def delete(resource_group, service_name, version_set_id, if_match=None):
    '''
    Deletes specific Api Version Set.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    - version_set_id -- A resource identifier for the related ApiVersionSet.

    Optional Parameters:
    - if_match -- ETag of the Entity.
    '''
    return _call_az("az apim api versionset delete", locals())




'''
Manage the user accounts of a Batch compute node.
'''
from .... pyaz_utils import _call_az

def create(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, expiry_time=None, is_admin=None, json_file=None, name=None, password=None, ssh_public_key=None):
    '''
    Add a user account to a Batch compute node.

    Required Parameters:
    - node_id -- The ID of the machine on which you want to create a user Account.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expiry_time -- If omitted, the default is 1 day from the current time. For Linux Compute Nodes, the expiryTime has a precision up to a day. Expected format is an ISO-8601 timestamp.
    - is_admin -- Whether the Account should be an administrator on the Compute Node. The default value is false. True if flag present.
    - json_file -- A file containing the user specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'User Arguments' are ignored.
    - name -- Required.
    - password -- The password is required for Windows Compute Nodes (those created with 'cloudServiceConfiguration', or created with 'virtualMachineConfiguration' using a Windows Image reference). For Linux Compute Nodes, the password can optionally be specified along with the sshPublicKey property.
    - ssh_public_key -- The public key should be compatible with OpenSSH encoding and should be base 64 encoded. This property can be specified only for Linux Compute Nodes. If this is specified for a Windows Compute Node, then the Batch service rejects the request; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request).
    '''
    return _call_az("az batch node user create", locals())


def delete(node_id, pool_id, user_name, account_endpoint=None, account_key=None, account_name=None, yes=None):
    '''
    

    Required Parameters:
    - node_id -- The ID of the machine on which you want to delete a user Account.
    - pool_id -- The ID of the Pool that contains the Compute Node.
    - user_name -- The name of the user Account to delete.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch node user delete", locals())


def reset(node_id, pool_id, user_name, account_endpoint=None, account_key=None, account_name=None, expiry_time=None, json_file=None, password=None, ssh_public_key=None):
    '''
    Update the properties of a user account on a Batch compute node. Unspecified properties which can be updated are reset to their defaults.

    Required Parameters:
    - node_id -- The ID of the machine on which you want to update a user Account.
    - pool_id -- The ID of the Pool that contains the Compute Node.
    - user_name -- The name of the user Account to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expiry_time -- If omitted, the default is 1 day from the current time. For Linux Compute Nodes, the expiryTime has a precision up to a day. Expected format is an ISO-8601 timestamp.
    - json_file -- A file containing the node update user parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Node Update User Arguments' are ignored.
    - password -- The password is required for Windows Compute Nodes (those created with 'cloudServiceConfiguration', or created with 'virtualMachineConfiguration' using a Windows Image reference). For Linux Compute Nodes, the password can optionally be specified along with the sshPublicKey property. If omitted, any existing password is removed.
    - ssh_public_key -- The public key should be compatible with OpenSSH encoding and should be base 64 encoded. This property can be specified only for Linux Compute Nodes. If this is specified for a Windows Compute Node, then the Batch service rejects the request; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). If omitted, any existing SSH public key is removed.
    '''
    return _call_az("az batch node user reset", locals())




from ... pyaz_utils import _call_az

def create(definitions, name, definition_groups=None, description=None, display_name=None, management_group=None, metadata=None, params=None, subscription=None):
    '''
    Create a policy set definition.

    Required Parameters:
    - definitions -- JSON formatted string or a path to a file or uri containing definitions.
    - name -- Name of the new policy set definition.

    Optional Parameters:
    - definition_groups -- JSON formatted string or a path to a file or uri containing policy definition groups. Groups are used to organize policy definitions within a policy set.
    - description -- Description of policy set definition.
    - display_name -- Display name of policy set definition.
    - management_group -- The name of the management group of the policy [set] definition.
    - metadata -- Metadata in space-separated key=value pairs.
    - params -- JSON formatted string or a path to a file or uri with parameter definitions.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy set-definition create", locals())


def delete(name, management_group=None, subscription=None):
    '''
    Delete a policy set definition.

    Required Parameters:
    - name -- The policy set definition name.

    Optional Parameters:
    - management_group -- The name of the management group of the policy [set] definition.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy set-definition delete", locals())


def list(management_group=None, subscription=None):
    '''
    List policy set definitions.

    Optional Parameters:
    - management_group -- The name of the management group of the policy [set] definition.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy set-definition list", locals())


def show(name, management_group=None, subscription=None):
    '''
    Show a policy set definition.

    Required Parameters:
    - name -- The policy set definition name.

    Optional Parameters:
    - management_group -- The name of the management group of the policy [set] definition.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy set-definition show", locals())


def update(name, definition_groups=None, definitions=None, description=None, display_name=None, management_group=None, metadata=None, params=None, subscription=None):
    '''
    Update a policy set definition.

    Required Parameters:
    - name -- The policy set definition name.

    Optional Parameters:
    - definition_groups -- JSON formatted string or a path to a file or uri containing policy definition groups. Groups are used to organize policy definitions within a policy set.
    - definitions -- JSON formatted string or a path to a file or uri containing definitions.
    - description -- Description of policy set definition.
    - display_name -- Display name of policy set definition.
    - management_group -- The name of the management group of the policy [set] definition.
    - metadata -- Metadata in space-separated key=value pairs.
    - params -- JSON formatted string or a path to a file or uri with parameter definitions.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy set-definition update", locals())




from .... pyaz_utils import _call_az

def add(account_name, allowed_clients, cifs, nfsv3, nfsv41, pool_name, resource_group, rule_index, unix_read_only, unix_read_write, volume_name, add=None, force_string=None, remove=None, set=None):
    '''
    Add a new rule to the export policy for a volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - allowed_clients -- None
    - cifs -- Indication that CIFS protocol is allowed
    - nfsv3 -- Indication that NFSv3 protocol is allowed
    - nfsv41 -- Indication that NFSv4.1 protocol is allowed
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_index -- None
    - unix_read_only -- Indication of read only access
    - unix_read_write -- Indication of read and write access
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az netappfiles volume export-policy add", locals())


def list(account_name, pool_name, resource_group, volume_name):
    '''
    List the export policy rules for a volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume export-policy list", locals())


def remove(account_name, pool_name, resource_group, rule_index, volume_name, add=None, force_string=None, remove=None, set=None):
    '''
    Remove a rule from the export policy for a volume by rule index. The current rules can be obtained by performing the subgroup list command.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_index -- None
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az netappfiles volume export-policy remove", locals())




'''
Manage Batch compute node files.
'''
from .... pyaz_utils import _call_az

def delete(file_path, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, recursive=None, yes=None):
    '''
    

    Required Parameters:
    - file_path -- The path to the file or directory that you want to delete.
    - node_id -- The ID of the Compute Node from which you want to delete the file.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - recursive -- Whether to delete children of a directory. If the filePath parameter represents a directory instead of a file, you can set recursive to true to delete the directory and all of the files and subdirectories in it. If recursive is false then the directory must be empty or deletion will fail.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch node file delete", locals())


def download(destination, file_path, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, end_range=None, if_modified_since=None, if_unmodified_since=None, start_range=None):
    '''
    Download the content of the a node file.

    Required Parameters:
    - destination -- The path to the destination file or directory.
    - file_path -- The path to the Compute Node file that you want to get the content of.
    - node_id -- The ID of the Compute Node that contains the file.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - end_range -- The byte range to be retrieved. If not set the file will be retrieved to the end.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - start_range -- The byte range to be retrieved. If not set the file will be retrieved from the beginning.
    '''
    return _call_az("az batch node file download", locals())


def show(file_path, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, if_modified_since=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - file_path -- The path to the Compute Node file that you want to get the properties of.
    - node_id -- The ID of the Compute Node that contains the file.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch node file show", locals())


def list(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, filter=None, recursive=None):
    '''
    

    Required Parameters:
    - node_id -- The ID of the Compute Node whose files you want to list.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-compute-node-files.
    - recursive -- Whether to list children of a directory.
    '''
    return _call_az("az batch node file list", locals())




from ... pyaz_utils import _call_az

def list(resource_group, solution_name):
    '''
    List all IoT security Analytics metrics.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - solution_name -- Name of the IoT Security solution
    '''
    return _call_az("az security iot-analytics list", locals())


def show(resource_group, solution_name):
    '''
    Shows IoT Security Analytics metrics.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - solution_name -- Name of the IoT Security solution
    '''
    return _call_az("az security iot-analytics show", locals())




from .... pyaz_utils import _call_az

def create(name, properties, resource_group, migration_name=None):
    '''
    Create a new migration workflow for a flexible server.

    Required Parameters:
    - name -- Migration target server name.
    - properties -- Request properties. Use double or no quotes to pass in filepath as argument.
    - resource_group -- Resource Group Name of the migration target server.

    Optional Parameters:
    - migration_name -- Name of the migration.
    '''
    return _call_az("az postgres flexible-server migration create", locals())


def show(migration_name, name, resource_group, level=None):
    '''
    Get the details of a specific migration.

    Required Parameters:
    - migration_name -- Name of the migration.
    - name -- Migration target server name.
    - resource_group -- Resource Group Name of the migration target server.

    Optional Parameters:
    - level -- Specify the level of migration details requested. Valid values are Active and All. Active is the default.
    '''
    return _call_az("az postgres flexible-server migration show", locals())


def list(name, resource_group, filter=None):
    '''
    List the migrations of a flexible server.

    Required Parameters:
    - name -- Migration target server name.
    - resource_group -- Resource Group Name of the migration target server.

    Optional Parameters:
    - filter -- Indicate whether all the migrations or just the Active migrations are returned. Active is the default. Valid values are: Active, All.
    '''
    return _call_az("az postgres flexible-server migration list", locals())


def update(migration_name, name, resource_group, cutover=None, db_names=None, overwrite_dbs=None, setup_replication=None, start_data_migration=None):
    '''
    Update a specific migration.

    Required Parameters:
    - migration_name -- Name of the migration.
    - name -- Migration target server name.
    - resource_group -- Resource Group Name of the migration target server.

    Optional Parameters:
    - cutover -- Cut-over the data migration. After this is complete, subsequent updates to the source DB will not be migrated to the target.
    - db_names -- Space-separated list of DBs to migrate. A minimum of 1 and a maximum of 8 DBs can be specified. You can migrate more DBs concurrently using additional migrations. Note that each additional DB affects the performance of the source server.
    - overwrite_dbs -- Allow the migration workflow to overwrite the DB on the target.
    - setup_replication -- Allow the migration workflow to setup logical replication on the source. Note that this command will restart the source server.
    - start_data_migration -- Reschedule the data migration to start right now.
    '''
    return _call_az("az postgres flexible-server migration update", locals())


def delete(migration_name, name, resource_group, yes=None):
    '''
    Delete a specific migration.

    Required Parameters:
    - migration_name -- Name of the migration.
    - name -- Migration target server name.
    - resource_group -- Resource Group Name of the migration target server.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az postgres flexible-server migration delete", locals())


def check_name_availability(migration_name, name, resource_group):
    '''
    Checks if the provided migration-name can be used.

    Required Parameters:
    - migration_name -- Name of the migration.
    - name -- Migration target server name.
    - resource_group -- Resource Group Name of the migration target server.
    '''
    return _call_az("az postgres flexible-server migration check-name-availability", locals())




'''
Manage extensions on a VM scale set.
'''
from ... pyaz_utils import _call_az
from . import image


def delete(name, resource_group, vmss_name, no_wait=None):
    '''
    Delete an extension from a VMSS.

    Required Parameters:
    - name -- Name of the extension.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss extension delete", locals())


def show(name, resource_group, vmss_name):
    '''
    Show details on a VMSS extension.

    Required Parameters:
    - name -- Name of the extension.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    '''
    return _call_az("az vmss extension show", locals())


def set(name, publisher, resource_group, vmss_name, enable_auto_upgrade=None, extension_instance_name=None, force_update=None, no_auto_upgrade_minor_version=None, no_wait=None, protected_settings=None, provision_after_extensions=None, settings=None, version=None):
    '''
    Add an extension to a VMSS or update an existing extension.

    Required Parameters:
    - name -- Name of the extension.
    - publisher -- The name of the extension publisher.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`

    Optional Parameters:
    - enable_auto_upgrade -- Indicate the extension should be automatically upgraded by the platform if there is a newer version of the extension available.
    - extension_instance_name -- Name of extension instance, which can be customized. Default: name of the extension.
    - force_update -- force to update even if the extension configuration has not changed.
    - no_auto_upgrade_minor_version -- If set, the extension service will not automatically pick or upgrade to the latest minor version, even if the extension is redeployed.
    - no_wait -- Do not wait for the long-running operation to finish.
    - protected_settings -- Protected settings in JSON format for sensitive information like credentials. A JSON file path is also accepted.
    - provision_after_extensions -- Space-separated list of extension names after which this extension should be provisioned. These extensions must already be set on the vm.
    - settings -- Extension settings in JSON format. A JSON file path is also accepted.
    - version -- The version of the extension. To pin extension version to this value, please specify --no-auto-upgrade-minor-version.
    '''
    return _call_az("az vmss extension set", locals())


def list(resource_group, vmss_name):
    '''
    List extensions associated with a VMSS.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vmss_name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    '''
    return _call_az("az vmss extension list", locals())


def upgrade(name, resource_group, no_wait=None):
    '''
    Upgrade all extensions for all VMSS instances to the latest version.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss extension upgrade", locals())




'''
Manage configuration values for a server.
'''
from .... pyaz_utils import _call_az

def set(name, resource_group, server_name, value=None):
    '''
    Update the configuration of a server.

    Required Parameters:
    - name -- The name of the configuration
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - value -- Value of the configuration. If not provided, configuration value will be set to default.
    '''
    return _call_az("az mariadb server configuration set", locals())


def show(name, resource_group, server_name):
    '''
    Get the configuration for a server."

    Required Parameters:
    - name -- The name of the server configuration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mariadb server configuration show", locals())


def list(resource_group, server_name):
    '''
    List the configuration values for a server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mariadb server configuration list", locals())




'''
Manage kusto pool database with synapse
'''
from .... pyaz_utils import _call_az

def list(kusto_pool_name, resource_group, workspace_name):
    '''
    Returns the list of databases of the given Kusto pool.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto database list", locals())


def show(database_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns a database.

    Required Parameters:
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto database show", locals())


def create(database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, read_write_database=None):
    '''
    Create a database.

    Required Parameters:
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - read_write_database -- Class representing a read write database.
    '''
    return _call_az("az synapse kusto database create", locals())


def update(database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, read_write_database=None):
    '''
    Updates a database.

    Required Parameters:
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - read_write_database -- Class representing a read write database.
    '''
    return _call_az("az synapse kusto database update", locals())


def delete(database_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes the database with the given name.

    Required Parameters:
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse kusto database delete", locals())


def wait(database_name, kusto_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto database is met.

    Required Parameters:
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse kusto database wait", locals())




'''
Restore backed up items from recovery points in a Recovery Services vault.
'''
from ... pyaz_utils import _call_az
from . import files


def restore_disks(container_name, item_name, resource_group, rp_name, storage_account, vault_name, disk_encryption_set_id=None, diskslist=None, mi_system_assigned=None, mi_user_assigned=None, rehydration_duration=None, rehydration_priority=None, restore_as_unmanaged_disks=None, restore_only_osdisk=None, restore_to_staging_storage_account=None, target_resource_group=None, target_zone=None, use_secondary_region=None):
    '''
    Restore disks of the backed VM from the specified recovery point.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rp_name -- Name of the recovery point.
    - storage_account -- Name or ID of the staging storage account. The VM configuration will be restored to this storage account. See the help for --restore-to-staging-storage-account parameter for more info.
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - disk_encryption_set_id -- The disk encryption set id is used for encrypting restored disks. Please ensure access to disk encryption set id that is specified here.
    - diskslist -- List of disks to be excluded or included.
    - mi_system_assigned -- Use this flag to specify whether a system-assigned managed identity should be used for the restore operation. MI option is not applicable for restoring unmanaged disks.
    - mi_user_assigned -- ARM ID of the user-assigned managed identity to use for the restore operation. Specify a value for this parameter if you do not want to use a system-assigned MI for restoring the backup item.
    - rehydration_duration -- Set the maximum time, in days (between 10-30, both inclusive) for which the recovery point stays in hydrated state.
    - rehydration_priority -- The type of priority to be maintained while rehydrating a recovery point 
    - restore_as_unmanaged_disks -- Use this flag to specify to restore as unmanaged disks
    - restore_only_osdisk -- Use this flag to restore only OS disks of a backed up VM.
    - restore_to_staging_storage_account -- Use this flag when you want disks to be restored to the staging storage account using the --storage-account parameter. When not specified, disks will be restored to their original storage accounts. Default: false.
    - target_resource_group -- Use this to specify the target resource group in which the restored disks will be saved
    - target_zone -- A primary region currently can have three Azure availability zones. Use this argument to specify the target zone number while doing Cross Zonal Restore.
    - use_secondary_region -- Use this flag to restore from a recoverypoint in secondary region.
    '''
    return _call_az("az backup restore restore-disks", locals())


def restore_azurefileshare(container_name, item_name, resolve_conflict, resource_group, restore_mode, rp_name, vault_name, target_file_share=None, target_folder=None, target_storage_account=None):
    '''
    Restore backed up Azure file shares to the same file-share or another file-share in registered storage accounts.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resolve_conflict -- Instruction if there's a conflict with the restored data.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - restore_mode -- Specify the restore mode.
    - rp_name -- Name of the recovery point.
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - target_file_share -- Destination file share to which content will be restored
    - target_folder -- Destination folder to which content will be restored. To restore content to root , leave the folder name empty
    - target_storage_account -- Destination storage account to which content will be restored
    '''
    return _call_az("az backup restore restore-azurefileshare", locals())


def restore_azurefiles(container_name, item_name, resolve_conflict, resource_group, restore_mode, rp_name, vault_name, source_file_path=None, source_file_type=None, target_file_share=None, target_folder=None, target_storage_account=None):
    '''
    Restore backed up Azure files within a file-share to the same file-share or another file-share in registered storage accounts.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resolve_conflict -- Instruction if there's a conflict with the restored data.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - restore_mode -- Specify the restore mode.
    - rp_name -- Name of the recovery point.
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - source_file_path -- The absolute path of the file, to be restored within the file share, as a string. This path is the same path used in the 'az storage file download' or 'az storage file show' CLI commands.
    - source_file_type -- Specify the source file type to be selected
    - target_file_share -- Destination file share to which content will be restored
    - target_folder -- Destination folder to which content will be restored. To restore content to root , leave the folder name empty
    - target_storage_account -- Destination storage account to which content will be restored
    '''
    return _call_az("az backup restore restore-azurefiles", locals())


def restore_azurewl(recovery_config, resource_group, vault_name, rehydration_duration=None, rehydration_priority=None, use_secondary_region=None):
    '''
    Restore backed up Azure Workloads in a Recovery services vault to another registered container or to the same container.

    Required Parameters:
    - recovery_config -- Specify the recovery configuration of a backed up item. The configuration object can be obtained from 'backup recoveryconfig show' command.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - rehydration_duration -- Set the maximum time, in days (between 10-30, both inclusive) for which the recovery point stays in hydrated state.
    - rehydration_priority -- The type of priority to be maintained while rehydrating a recovery point 
    - use_secondary_region -- Use this flag to restore from a recoverypoint in secondary region.
    '''
    return _call_az("az backup restore restore-azurewl", locals())




from .... pyaz_utils import _call_az

def add(name, subscription):
    '''
    Add a subscription to a management group.

    Required Parameters:
    - name -- None
    - subscription -- Name or ID of subscription.
    '''
    return _call_az("az account management-group subscription add", locals())


def remove(name, subscription):
    '''
    Remove an existing subscription from a management group.

    Required Parameters:
    - name -- None
    - subscription -- Name or ID of subscription.
    '''
    return _call_az("az account management-group subscription remove", locals())




'''
Manage files in Azure Data Lake Storage Gen2 account.
'''
from .... pyaz_utils import _call_az
from . import metadata


def create(account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, metadata=None, permissions=None, sas_token=None, timeout=None, umask=None):
    '''
    Create a new file in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - permissions -- POSIX access permissions for the file owner, the file owning group, and others. Each class may be granted read, write, or execute permission. The sticky bit is also supported. Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are supported. For more information, please refer to https://docs.microsoft.com/azure/storage/blobs/data-lake-storage-access-control#levels-of-permission.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - umask -- When creating a file or directory and the parent folder does not have a default ACL, the umask restricts the permissions of the file or directory to be created. The resulting permission is given by p & ^u, where p is the permission and u is the umask. For more information, please refer to https://docs.microsoft.com/azure/storage/blobs/data-lake-storage-access-control#umask.
    '''
    return _call_az("az storage fs file create", locals())


def upload(source, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, metadata=None, overwrite=None, permissions=None, sas_token=None, timeout=None, umask=None):
    '''
    Upload a file to a file path in ADLS Gen2 file system.

    Required Parameters:
    - source -- Path of the local file to upload as the file content.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - if_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- A Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z').
    - if_none_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified.
    - if_unmodified_since -- A Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z').
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - overwrite -- Overwrite an existing file when specified.
    - permissions -- POSIX access permissions for the file owner, the file owning group, and others. Each class may be granted read, write, or execute permission. The sticky bit is also supported. Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are supported. For more information, please refer to https://docs.microsoft.com/azure/storage/blobs/data-lake-storage-access-control#levels-of-permission.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - umask -- When creating a file or directory and the parent folder does not have a default ACL, the umask restricts the permissions of the file or directory to be created. The resulting permission is given by p & ^u, where p is the permission and u is the umask. For more information, please refer to https://docs.microsoft.com/azure/storage/blobs/data-lake-storage-access-control#umask.
    '''
    return _call_az("az storage fs file upload", locals())


def exists(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a file in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs file exists", locals())


def append(content, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Append content to a file in ADLS Gen2 file system.

    Required Parameters:
    - content -- Content to be appended to file.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs file append", locals())


def download(account_key=None, account_name=None, auth_mode=None, connection_string=None, destination=None, overwrite=None, sas_token=None, timeout=None):
    '''
    Download a file from the specified path in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - destination -- The local file where the file or folder will be downloaded to. The source filename will be used if not specified.
    - overwrite -- Overwrite an existing file when specified. Default value is false.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs file download", locals())


def show(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show properties of file in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs file show", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, exclude_dir=None, marker=None, num_results=None, path=None, recursive=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List files and directories in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - exclude_dir -- List only files in the given file system.
    - marker -- An opaque continuation token. This value can be retrieved from the next_marker field of a previous generator object. If specified, this generator will begin returning results from this point.
    - num_results -- Specify the maximum number of results to return. If the request does not specify num_results or specifies a value greater than 5,000, the server will return up to 5,000 items.
    - path -- Filter the results to return only paths under the specified path.
    - recursive -- Look into sub-directories recursively when set to true.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - show_next_marker -- Show nextMarker in result when specified.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs file list", locals())


def move(new_path, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, sas_token=None):
    '''
    Move a file in ADLS Gen2 Account.

    Required Parameters:
    - new_path -- The new path the users want to move to. The value must have the following format: "{filesystem}/{directory}/{subdirectory}/{file}".

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage fs file move", locals())


def delete(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None, yes=None):
    '''
    Delete a file in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage fs file delete", locals())




'''
Manage Azure SQL Databases and Data Warehouses.
'''
from .. pyaz_utils import _call_az
from . import db, dw, elastic_pool, failover_group, instance_failover_group, instance_pool, midb, stg, virtual_cluster, vm


def list_usages(location):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az sql list-usages", locals())


def show_usage(location, usage):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - usage -- Name of usage metric to return.
    '''
    return _call_az("az sql show-usage", locals())




'''
Manage AFD endpoints within the specified profile.
'''
from ... pyaz_utils import _call_az

def show(endpoint_name, profile_name, resource_group):
    '''
    Show details of an endpoint within the specified profile.

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd endpoint show", locals())


def list(profile_name, resource_group):
    '''
    List all the endpoints within the specified profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd endpoint list", locals())


def purge(content_paths, endpoint_name, profile_name, resource_group, domains=None, no_wait=None):
    '''
    Removes cached contents from Azure Front Door.

    Required Parameters:
    - content_paths -- The path to the content to be purged. Can describe a file path or a wildcard directory.
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - domains -- List of domains.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az afd endpoint purge", locals())


def delete(endpoint_name, profile_name, resource_group, yes=None):
    '''
    Delete an endpoint within the specified profile.

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd endpoint delete", locals())


def update(endpoint_name, profile_name, resource_group, enabled_state=None, origin_response_timeout_seconds=None, tags=None):
    '''
    Update an endpoint within the specified profile.

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enabled_state -- Whether to enable this endpoint.
    - origin_response_timeout_seconds -- Send and receive timeout on forwarding request to the origin. When timeout is reached, the request fails and returns.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az afd endpoint update", locals())


def create(enabled_state, endpoint_name, origin_response_timeout_seconds, profile_name, resource_group, tags=None):
    '''
    Creates an endpoint within the specified profile.

    Required Parameters:
    - enabled_state -- Whether to enable this endpoint.
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - origin_response_timeout_seconds -- Send and receive timeout on forwarding request to the origin. When timeout is reached, the request fails and returns.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az afd endpoint create", locals())




from .. pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List all deployment scripts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deployment-scripts list", locals())


def show(name, resource_group):
    '''
    Retrieve a deployment script.

    Required Parameters:
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deployment-scripts show", locals())


def show_log(name, resource_group):
    '''
    Show deployment script logs.

    Required Parameters:
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az deployment-scripts show-log", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a deployment script.

    Required Parameters:
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az deployment-scripts delete", locals())




'''
Manage contacts for certificate management.
'''
from .... pyaz_utils import _call_az

def list(vault_name):
    '''
    

    Required Parameters:
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate contact list", locals())


def add(email, vault_name, name=None, phone=None):
    '''
    

    Required Parameters:
    - email -- Contact e-mail address. Must be unique.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - name -- Full contact name.
    - phone -- Contact phone number.
    '''
    return _call_az("az keyvault certificate contact add", locals())


def delete(email, vault_name):
    '''
    

    Required Parameters:
    - email -- Contact e-mail address. Must be unique.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate contact delete", locals())




from .... pyaz_utils import _call_az

def add(account_name, action=None, ip_address=None, resource_group=None, resource_id=None, subnet=None, tenant_id=None, vnet_name=None):
    '''
    Add a network rule.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - action -- The action of virtual network rule. Possible value is Allow.
    - ip_address -- IPv4 address or CIDR range.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_id -- The resource id to add in network rule.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - tenant_id -- The tenant id to add in network rule.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az storage account network-rule add", locals())


def list(account_name, resource_group=None):
    '''
    List network rules.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account network-rule list", locals())


def remove(account_name, ip_address=None, resource_group=None, resource_id=None, subnet=None, tenant_id=None, vnet_name=None):
    '''
    Remove a network rule.

    Required Parameters:
    - account_name -- The storage account name.

    Optional Parameters:
    - ip_address -- IPv4 address or CIDR range.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_id -- The resource id to add in network rule.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - tenant_id -- The tenant id to add in network rule.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az storage account network-rule remove", locals())




'''
Manage creator with maps
'''
from ... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    Get all Creator instances for an Azure Maps Account.

    Required Parameters:
    - name -- The name of the maps account
    - resource_group -- Resource group name
    '''
    return _call_az("az maps creator list", locals())


def show(creator_name, name, resource_group):
    '''
    Get a Maps Creator resource.

    Required Parameters:
    - creator_name -- The name of the Maps Creator instance.
    - name -- The name of the maps account
    - resource_group -- Resource group name
    '''
    return _call_az("az maps creator show", locals())


def create(creator_name, name, resource_group, storage_units, location=None, tags=None):
    '''
    Create a Maps Creator resource. Creator resource will manage Azure resources required to populate a custom set of mapping data. It requires an account to exist before it can be created.

    Required Parameters:
    - creator_name -- The name of the Maps Creator instance.
    - name -- The name of the maps account
    - resource_group -- Resource group name
    - storage_units -- The storage units to be allocated. Integer values from 1 to 100, inclusive.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az maps creator create", locals())


def update(creator_name, name, resource_group, storage_units=None, tags=None):
    '''
    Updates the Maps Creator resource. Only a subset of the parameters may be updated after creation, such as Tags.

    Required Parameters:
    - creator_name -- The name of the Maps Creator instance.
    - name -- The name of the maps account
    - resource_group -- Resource group name

    Optional Parameters:
    - storage_units -- The storage units to be allocated. Integer values from 1 to 100, inclusive.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az maps creator update", locals())


def delete(creator_name, name, resource_group, yes=None):
    '''
    Delete a Maps Creator resource.

    Required Parameters:
    - creator_name -- The name of the Maps Creator instance.
    - name -- The name of the maps account
    - resource_group -- Resource group name

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az maps creator delete", locals())




'''
Manage Azure NetApp Files (ANF) Account Resources.
'''
from ... pyaz_utils import _call_az
from . import ad, backup, backup_policy


def show(name, resource_group):
    '''
    Get the specified ANF account.

    Required Parameters:
    - name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account show", locals())


def delete(name, resource_group):
    '''
    Delete the specified ANF account.

    Required Parameters:
    - name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account delete", locals())


def list(resource_group=None):
    '''
    List ANF accounts by subscription or by resource group name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account list", locals())


def create(location, name, resource_group, encryption=None, tags=None):
    '''
    Create a new Azure NetApp Files (ANF) account. Note that active directories are added using the subgroup commands.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - encryption -- Encryption settings.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az netappfiles account create", locals())


def update(name, resource_group, add=None, encryption=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Set/modify the tags for a specified ANF account.

    Required Parameters:
    - name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - encryption -- Encryption settings.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az netappfiles account update", locals())




'''
Manage role definitions.
'''
from ... pyaz_utils import _call_az

def list(custom_role_only=None, name=None, resource_group=None, scope=None):
    '''
    List role definitions.

    Optional Parameters:
    - custom_role_only -- custom roles only(vs. build-in ones)
    - name -- the role's name
    - resource_group -- use it only if the role or assignment was added at the level of a resource group
    - scope -- scope at which the role assignment or definition applies to, e.g., /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333, /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup, or /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM
    '''
    return _call_az("az role definition list", locals())


def delete(name, custom_role_only=None, resource_group=None, scope=None):
    '''
    Delete a role definition.

    Required Parameters:
    - name -- the role's name

    Optional Parameters:
    - custom_role_only -- custom roles only(vs. build-in ones)
    - resource_group -- use it only if the role or assignment was added at the level of a resource group
    - scope -- scope at which the role assignment or definition applies to, e.g., /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333, /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup, or /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM
    '''
    return _call_az("az role definition delete", locals())


def create(role_definition):
    '''
    Create a custom role definition.

    Required Parameters:
    - role_definition -- json formatted content which defines the new role.
    '''
    return _call_az("az role definition create", locals())


def update(role_definition):
    '''
    Update a role definition.

    Required Parameters:
    - role_definition -- json formatted content which defines the new role.
    '''
    return _call_az("az role definition update", locals())




from ... pyaz_utils import _call_az

def create(account_name, name, resource_group, cbcs_clear_tracks=None, cbcs_default_key_label=None, cbcs_default_key_policy_name=None, cbcs_fair_play_allow_persistent_license=None, cbcs_fair_play_template=None, cbcs_key_to_track_mappings=None, cbcs_play_ready_attributes=None, cbcs_play_ready_template=None, cbcs_protocols=None, cbcs_widevine_template=None, cenc_clear_tracks=None, cenc_default_key_label=None, cenc_default_key_policy_name=None, cenc_disable_play_ready=None, cenc_disable_widevine=None, cenc_key_to_track_mappings=None, cenc_play_ready_attributes=None, cenc_play_ready_template=None, cenc_protocols=None, cenc_widevine_template=None, default_content_key_policy_name=None, envelope_clear_tracks=None, envelope_default_key_label=None, envelope_default_key_policy_name=None, envelope_key_to_track_mappings=None, envelope_protocols=None, envelope_template=None, no_encryption_protocols=None):
    '''
    Create a streaming policy.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - cbcs_clear_tracks -- The JSON representing which tracks should not be encrypted. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streamingpolicies/create#trackselection
    - cbcs_default_key_label -- Label to specify Default Content Key for an encryption scheme.
    - cbcs_default_key_policy_name -- Policy used by Default Content Key.
    - cbcs_fair_play_allow_persistent_license -- Allows the license to be persistent or not.
    - cbcs_fair_play_template -- The custom license acquisition URL template for a customer service to deliver keys to end users. Not needed when using Azure Media Services for issuing keys.
    - cbcs_key_to_track_mappings -- The JSON representing a list of StreamingPolicyContentKey. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streamingpolicies/create#streamingpolicycontentkey
    - cbcs_play_ready_attributes -- Custom attributes for PlayReady.
    - cbcs_play_ready_template -- The custom license acquisition URL template for a customer service to deliver keys to end users. Not needed when using Azure Media Services for issuing keys.
    - cbcs_protocols -- Space-separated list of enabled protocols for Common Encryption CBCS. Allowed values: Download, Dash, HLS, SmoothStreaming.
    - cbcs_widevine_template -- The custom license acquisition URL template for a customer service to deliver keys to end users. Not needed when using Azure Media Services for issuing keys.
    - cenc_clear_tracks -- The JSON representing which tracks should not be encrypted. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streamingpolicies/create#trackselection
    - cenc_default_key_label -- Label to specify Default Content Key for an encryption scheme.
    - cenc_default_key_policy_name -- Policy used by Default Content Key.
    - cenc_disable_play_ready -- If specified, no PlayReady cenc DRM will be configured. If --cenc-disable-play-ready is set, --cenc-disable-widevine cannot also be set.
    - cenc_disable_widevine -- If specified, no Widevine cenc DRM will be configured. If --cenc-disable-widevine is set, --cenc-disable-play-ready cannot also be set.
    - cenc_key_to_track_mappings -- The JSON representing a list of StreamingPolicyContentKey. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streamingpolicies/create#streamingpolicycontentkey
    - cenc_play_ready_attributes -- Custom attributes for PlayReady.
    - cenc_play_ready_template -- The custom license acquisition URL template for a customer service to deliver keys to end users. Not needed when using Azure Media Services for issuing keys.
    - cenc_protocols -- Space-separated list of enabled protocols for Common Encryption CENC. Allowed values: Download, Dash, HLS, SmoothStreaming.
    - cenc_widevine_template -- The custom license acquisition URL template for a customer service to deliver keys to end users. Not needed when using Azure Media Services for issuing keys.
    - default_content_key_policy_name -- Default Content Key used by current streaming policy.
    - envelope_clear_tracks -- The JSON representing which tracks should not be encrypted. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streamingpolicies/create#trackselection
    - envelope_default_key_label -- Label used to specify Content Key when creating a streaming locator.
    - envelope_default_key_policy_name -- Policy used by Default Key.
    - envelope_key_to_track_mappings -- The JSON representing a list of StreamingPolicyContentKey. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streamingpolicies/create#streamingpolicycontentkey
    - envelope_protocols -- Space-separated list of enabled protocols for Envelope Encryption. Allowed values: Download, Dash, HLS, SmoothStreaming.
    - envelope_template -- The KeyAcquistionUrlTemplate is used to point to user specified service to delivery content keys.
    - no_encryption_protocols -- Space-separated list of enabled protocols for NoEncryption. Allowed values: Download, Dash, HLS, SmoothStreaming.
    '''
    return _call_az("az ams streaming-policy create", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the streaming policies within an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- Restricts the set of items returned.
    - orderby -- Specifies the key by which the result collection should be ordered.
    - top -- Specifies a non-negative integer n that limits the number of items returned from a collection. The service returns the number of available items up to but not greater than the specified value n.
    '''
    return _call_az("az ams streaming-policy list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a streaming policy.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-policy show", locals())


def delete(account_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-policy delete", locals())




from ... pyaz_utils import _call_az

def list(resource_group, server_name, file_last_written=None, filename_contains=None, max_file_size=None):
    '''
    List log files for a server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Server.

    Optional Parameters:
    - file_last_written -- Integer in hours to indicate file last modify time, default value is 72.
    - filename_contains -- The pattern that file name should match.
    - max_file_size -- The file size limitation to filter files.
    '''
    return _call_az("az mariadb server-logs list", locals())


def download(name, resource_group, server_name):
    '''
    Download log files.

    Required Parameters:
    - name -- Space-separated list of log filenames on the server to download.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mariadb server-logs download", locals())




'''
Manage routes under an AFD endpoint.
'''
from ... pyaz_utils import _call_az

def show(endpoint_name, profile_name, resource_group, route_name):
    '''
    Show route details.

    Required Parameters:
    - endpoint_name -- Name of the endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_name -- Name of the route.
    '''
    return _call_az("az afd route show", locals())


def list(endpoint_name, profile_name, resource_group):
    '''
    List all the routes within the specified endpoint.

    Required Parameters:
    - endpoint_name -- Name of the endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd route list", locals())


def create(endpoint_name, forwarding_protocol, https_redirect, origin_group, profile_name, resource_group, route_name, supported_protocols, content_types_to_compress=None, custom_domains=None, enable_compression=None, link_to_default_domain=None, origin_path=None, patterns_to_match=None, query_string_caching_behavior=None, rule_sets=None):
    '''
    Creates a new route within the specified endpoint.

    Required Parameters:
    - endpoint_name -- Name of the endpoint.
    - forwarding_protocol -- Protocol this rule will use when forwarding traffic to backends.
    - https_redirect -- Whether to automatically redirect HTTP traffic to HTTPS traffic.
    - origin_group -- Name or ID of the origin group to be associated with.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_name -- Name of the route.
    - supported_protocols -- List of supported protocols for this route.

    Optional Parameters:
    - content_types_to_compress -- List of content types on which compression applies. The value should be a valid MIME type.
    - custom_domains -- Custom domains referenced by this endpoint.
    - enable_compression -- Indicates whether content compression is enabled on AzureFrontDoor. Default value is false. If compression is enabled, content will be served as compressed if user requests for a compressed version. Content won't be compressed on AzureFrontDoor when requested content is smaller than 1 byte or larger than 1 MB.
    - link_to_default_domain -- Whether this route will be linked to the default endpoint domain.
    - origin_path -- A directory path on the origin that AFD can use to retrieve content from. E.g, "/img/*"
    - patterns_to_match -- The route patterns of the rule.
    - query_string_caching_behavior -- Defines how CDN caches requests that include query strings. You can ignore any query strings when caching, bypass caching to prevent requests that contain query strings from being cached, or cache every request with a unique URL.
    - rule_sets -- Collection of ID or name of rule set referenced by the route.
    '''
    return _call_az("az afd route create", locals())


def update(endpoint_name, profile_name, resource_group, route_name, content_types_to_compress=None, custom_domains=None, enable_compression=None, forwarding_protocol=None, https_redirect=None, link_to_default_domain=None, origin_group=None, origin_path=None, patterns_to_match=None, query_string_caching_behavior=None, rule_sets=None, supported_protocols=None):
    '''
    Update an existing route within the specified endpoint.

    Required Parameters:
    - endpoint_name -- Name of the endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_name -- Name of the route.

    Optional Parameters:
    - content_types_to_compress -- List of content types on which compression applies. The value should be a valid MIME type.
    - custom_domains -- Custom domains referenced by this endpoint.
    - enable_compression -- Indicates whether content compression is enabled on AzureFrontDoor. Default value is false. If compression is enabled, content will be served as compressed if user requests for a compressed version. Content won't be compressed on AzureFrontDoor when requested content is smaller than 1 byte or larger than 1 MB.
    - forwarding_protocol -- Protocol this rule will use when forwarding traffic to backends.
    - https_redirect -- Whether to automatically redirect HTTP traffic to HTTPS traffic.
    - link_to_default_domain -- Whether this route will be linked to the default endpoint domain.
    - origin_group -- Name or ID of the origin group to be associated with.
    - origin_path -- A directory path on the origin that AFD can use to retrieve content from. E.g, "/img/*"
    - patterns_to_match -- The route patterns of the rule.
    - query_string_caching_behavior -- Defines how CDN caches requests that include query strings. You can ignore any query strings when caching, bypass caching to prevent requests that contain query strings from being cached, or cache every request with a unique URL.
    - rule_sets -- Collection of ID or name of rule set referenced by the route.
    - supported_protocols -- List of supported protocols for this route.
    '''
    return _call_az("az afd route update", locals())


def delete(endpoint_name, profile_name, resource_group, route_name, yes=None):
    '''
    Delete an existing route within the specified endpoint.

    Required Parameters:
    - endpoint_name -- Name of the endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - route_name -- Name of the route.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd route delete", locals())




'''
Manage web app deployments.
'''
from ... pyaz_utils import _call_az
from . import container, github_actions, slot, source, user


def list_publishing_profiles(name, resource_group, slot=None, xml=None):
    '''
    Get the details for available web app deployment profiles.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    - xml -- retrieves the publishing profile details in XML format
    '''
    return _call_az("az webapp deployment list-publishing-profiles", locals())


def list_publishing_credentials(name, resource_group, slot=None):
    '''
    Get the details for available web app publishing credentials

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp deployment list-publishing-credentials", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    Adaptive Application Controls - List
    '''
    return _call_az("az security adaptive-application-controls list", locals())


def show(group_name):
    '''
    Adaptive Application Controls - Get

    Required Parameters:
    - group_name -- Name of an application control VM/server group
    '''
    return _call_az("az security adaptive-application-controls show", locals())




'''
Manage certificate issuer information.
'''
from .... pyaz_utils import _call_az
from . import admin


def update(issuer_name, vault_name, account_id=None, enabled=None, organization_id=None, password=None, provider_name=None):
    '''
    

    Required Parameters:
    - issuer_name -- Certificate issuer name.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - account_id -- The issuer account id/username/etc.
    - enabled -- Set issuer enabled state.
    - organization_id -- The organization id.
    - password -- The issuer account password/secret/etc.
    - provider_name -- The certificate provider name. Must be registered with your tenant ID and in your region.
    '''
    return _call_az("az keyvault certificate issuer update", locals())


def list(vault_name, maxresults=None):
    '''
    

    Required Parameters:
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault certificate issuer list", locals())


def create(issuer_name, provider_name, vault_name, account_id=None, disabled=None, organization_id=None, password=None):
    '''
    

    Required Parameters:
    - issuer_name -- Certificate issuer name.
    - provider_name -- The certificate provider name. Must be registered with your tenant ID and in your region.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - account_id -- The issuer account id/username/etc.
    - disabled -- Set issuer to disabled state.
    - organization_id -- The organization id.
    - password -- The issuer account password/secret/etc.
    '''
    return _call_az("az keyvault certificate issuer create", locals())


def show(issuer_name, vault_name):
    '''
    

    Required Parameters:
    - issuer_name -- Certificate issuer name.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate issuer show", locals())


def delete(issuer_name, vault_name):
    '''
    

    Required Parameters:
    - issuer_name -- Certificate issuer name.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate issuer delete", locals())




'''
Manage delivery rule conditions for an endpoint.
'''
from ..... pyaz_utils import _call_az

def show(name, profile_name, resource_group):
    '''
    show delivery rules asscociate with the endpoint.

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn endpoint rule condition show", locals())


def add(match_variable, name, operator, profile_name, resource_group, rule_name, match_values=None, negate_condition=None, selector=None, transform=None):
    '''
    Add a condition to a delivery rule.

    Required Parameters:
    - match_variable -- Name of the match condition.
    - name -- Name of the CDN endpoint.
    - operator -- Operator of the match condition.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rule.

    Optional Parameters:
    - match_values -- Match values of the match condition (comma separated).
    - negate_condition -- If true, negates the condition
    - selector -- Selector of the match condition.
    - transform -- Transform to apply before matching.
    '''
    return _call_az("az cdn endpoint rule condition add", locals())


def remove(index, name, profile_name, resource_group, rule_name):
    '''
    Remove a condition from a delivery rule.

    Required Parameters:
    - index -- The index of the condition/action
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- Name of the rule.
    '''
    return _call_az("az cdn endpoint rule condition remove", locals())




'''
Manage credentials for App Configurations.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group=None):
    '''
    List access keys of an App Configuration.

    Required Parameters:
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appconfig credential list", locals())


def regenerate(id, name, resource_group=None):
    '''
    Regenerate an access key for an App Configuration.

    Required Parameters:
    - id -- Id of the key to be regenerated. Can be found using az appconfig credential list command.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appconfig credential regenerate", locals())




from .... pyaz_utils import _call_az

def list(database_rid, instance_id, location, end_time=None, start_time=None):
    '''
    List all the versions of all the sql containers that were created / modified / deleted in the given database and restorable account.

    Required Parameters:
    - database_rid -- Rid of the database
    - instance_id -- InstanceId of the Account
    - location -- Location

    Optional Parameters:
    - end_time -- The snapshot create timestamp before which snapshots need to be listed.
    - start_time -- The snapshot create timestamp after which snapshots need to be listed.
    '''
    return _call_az("az cosmosdb sql restorable-container list", locals())




from .... pyaz_utils import _call_az

def approve(description=None, id=None, name=None, resource_group=None, server_name=None):
    '''
    Approve the specified private endpoint connection associated with a PostgreSQL server.

    Optional Parameters:
    - description -- Comments for approve operation.
    - id -- The ID of the private endpoint connection associated with the Server. If specified --server-name/-s and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Server. Required if --id is not specified
    - resource_group -- The resource group name of specified server.
    - server_name -- Name of the Server. Required if --id is not specified
    '''
    return _call_az("az postgres server private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, resource_group=None, server_name=None):
    '''
    Reject the specified private endpoint connection associated with a PostgreSQL server.

    Optional Parameters:
    - description -- Comments for reject operation.
    - id -- The ID of the private endpoint connection associated with the Server. If specified --server-name/-s and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Server. Required if --id is not specified
    - resource_group -- The resource group name of specified server.
    - server_name -- Name of the Server. Required if --id is not specified
    '''
    return _call_az("az postgres server private-endpoint-connection reject", locals())


def delete(id=None, name=None, resource_group=None, server_name=None):
    '''
    Delete the specified private endpoint connection associated with a PostgreSQL server.

    Optional Parameters:
    - id -- The ID of the private endpoint connection associated with the Server. If specified --server-name/-s and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Server. Required if --id is not specified
    - resource_group -- The resource group name of specified server.
    - server_name -- Name of the Server. Required if --id is not specified
    '''
    return _call_az("az postgres server private-endpoint-connection delete", locals())


def show(id=None, name=None, resource_group=None, server_name=None):
    '''
    Show details of a private endpoint connection associated with a PostgreSQL server.

    Optional Parameters:
    - id -- The ID of the private endpoint connection associated with the Server. If specified --server-name/-s and --name/-n, this should be omitted.
    - name -- The name of the private endpoint connection associated with the Server. Required if --id is not specified
    - resource_group -- The resource group name of specified server.
    - server_name -- Name of the Server. Required if --id is not specified
    '''
    return _call_az("az postgres server private-endpoint-connection show", locals())




from ... pyaz_utils import _call_az

def list(resource_group, service_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search query-key list", locals())


def create(name, resource_group, service_name):
    '''
    

    Required Parameters:
    - name -- The name of the query key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search query-key create", locals())


def delete(key_value, resource_group, service_name):
    '''
    

    Required Parameters:
    - key_value -- The value of the query key.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search query-key delete", locals())




'''
Commands to manage Log Analytics monitoring in an ARO 3.11 cluster.
'''
from ... pyaz_utils import _call_az

def enable(name, resource_group, workspace_id, no_wait=None):
    '''
    Enable Log Analytics monitoring in an ARO 3.11 cluster.

    Required Parameters:
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_id -- The resource ID of an existing Log Analytics Workspace to use for storing monitoring data.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az openshift monitor enable", locals())


def disable(name, resource_group, no_wait=None):
    '''
    Disable Log Analytics monitoring in an ARO 3.11 cluster.

    Required Parameters:
    - name -- Name of the managed OpenShift cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az openshift monitor disable", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, workspace_name, description=None, if_match=None, no_wait=None):
    '''
    Create an self-hosted integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - description -- The integration runtime description.
    - if_match -- ETag of the integration runtime entity. Should only be specified for update, for which it should match existing entity or can be * for unconditional update.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse integration-runtime self-hosted create", locals())




'''
Entity which contains details of the job.
'''
from ... pyaz_utils import _call_az

def list(resource_group, vault_name, backup_management_type=None, end_date=None, operation=None, start_date=None, status=None, use_secondary_region=None):
    '''
    List all backup jobs of a Recovery Services vault.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - end_date -- The end date of the range in UTC (d-m-Y).
    - operation -- User initiated operation.
    - start_date -- The start date of the range in UTC (d-m-Y).
    - status -- Status of the Job.
    - use_secondary_region -- Use this flag to show recoverypoints in secondary region.
    '''
    return _call_az("az backup job list", locals())


def show(name, resource_group, vault_name, use_secondary_region=None):
    '''
    Show details of a particular job.

    Required Parameters:
    - name -- Name of the job. You can use the backup job list command to get the name of a job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - use_secondary_region -- Use this flag to show recoverypoints in secondary region.
    '''
    return _call_az("az backup job show", locals())


def stop(name, resource_group, vault_name, use_secondary_region=None):
    '''
    Suspend or terminate a currently running job.

    Required Parameters:
    - name -- Name of the job. You can use the backup job list command to get the name of a job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - use_secondary_region -- Use this flag to show recoverypoints in secondary region.
    '''
    return _call_az("az backup job stop", locals())


def wait(name, resource_group, vault_name, timeout=None, use_secondary_region=None):
    '''
    Wait until either the job completes or the specified timeout value is reached.

    Required Parameters:
    - name -- Name of the job. You can use the backup job list command to get the name of a job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - timeout -- Maximum time, in seconds, to wait before aborting.
    - use_secondary_region -- Use this flag to show recoverypoints in secondary region.
    '''
    return _call_az("az backup job wait", locals())




'''
Manage the Directline Channel on a bot.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, add_disabled=None, disablev1=None, disablev3=None, enable_enhanced_auth=None, trusted_origins=None):
    '''
    Create the DirectLine Channel on a bot with only v3 protocol enabled.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add_disabled -- Add the channel in a disabled state.
    - disablev1 -- If true, v1 protocol will be disabled on the channel
    - disablev3 -- If true, v3 protocol will be disabled on the channel.
    - enable_enhanced_auth -- If true, enables enhanced authentication features. Must be true for --trusted-origins parameters to work.
    - trusted_origins -- Space separated Trusted Origins URLs (must use HTTPS) e.g. --trusted-origins https://mybotsite1.azurewebsites.net https://mybotsite2.azurewebsites.net
    '''
    return _call_az("az bot directline create", locals())


def update(name, resource_group, add_disabled=None, disablev1=None, disablev3=None, enable_enhanced_auth=None, trusted_origins=None):
    '''
    Update the DirectLine Channel on a bot with only v3 protocol enabled.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add_disabled -- Add the channel in a disabled state.
    - disablev1 -- If true, v1 protocol will be disabled on the channel
    - disablev3 -- If true, v3 protocol will be disabled on the channel.
    - enable_enhanced_auth -- If true, enables enhanced authentication features. Must be true for --trusted-origins parameters to work.
    - trusted_origins -- Space separated Trusted Origins URLs (must use HTTPS) e.g. --trusted-origins https://mybotsite1.azurewebsites.net https://mybotsite2.azurewebsites.net
    '''
    return _call_az("az bot directline update", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Directline Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - with_secrets -- Show secrets in response for the channel.
    '''
    return _call_az("az bot directline show", locals())


def delete(name, resource_group):
    '''
    Delete the Directline Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az bot directline delete", locals())




from ... pyaz_utils import _call_az

def add(name, resource_group, subnet, vnet, skip_delegation_check=None, slot=None):
    '''
    Add a regional virtual network integration to a functionapp

    Required Parameters:
    - name -- name of the function app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- The name or resource ID of the subnet
    - vnet -- The name or resource ID of the Vnet

    Optional Parameters:
    - skip_delegation_check -- Skip check if you do not have permission or the VNet is in another subscription.
    - slot -- The name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp vnet-integration add", locals())


def list(name, resource_group, slot=None):
    '''
    list the virtual network integrations on a functionapp

    Required Parameters:
    - name -- name of the function app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp vnet-integration list", locals())


def remove(name, resource_group, slot=None):
    '''
    remove a regional virtual network integration from functionapp

    Required Parameters:
    - name -- name of the function app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp vnet-integration remove", locals())




'''
billing subscription
'''
from ... pyaz_utils import _call_az

def list(account_name, customer_name=None, invoice_section_name=None, profile_name=None):
    '''
    List the subscriptions for a billing account. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement or Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - customer_name -- The ID that uniquely identifies a customer.
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing subscription list", locals())


def show(account_name):
    '''
    Get a subscription by its ID. The operation is supported for billing accounts with agreement type Microsoft Customer Agreement and Microsoft Partner Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    '''
    return _call_az("az billing subscription show", locals())


def update(account_name, cost_center=None, sku_id=None, subscription_billing_status=None):
    '''
    Update the properties of a billing subscription. Currently, cost center can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - cost_center -- The cost center applied to the subscription.
    - sku_id -- The sku ID of the Azure plan for the subscription.
    - subscription_billing_status -- The current billing status of the subscription.
    '''
    return _call_az("az billing subscription update", locals())


def move(account_name, destination_invoice_section_id, no_wait=None):
    '''
    Moves a subscription's charges to a new invoice section. The new invoice section must belong to the same billing profile as the existing invoice section. This operation is supported for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - destination_invoice_section_id -- The destination invoice section id.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az billing subscription move", locals())


def validate_move(account_name, destination_invoice_section_id):
    '''
    Validate if a subscription's charges can be moved to a new invoice section. This operation is supported for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - destination_invoice_section_id -- The destination invoice section id.
    '''
    return _call_az("az billing subscription validate-move", locals())


def wait(account_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing subscription is met.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az billing subscription wait", locals())




from ... pyaz_utils import _call_az

def create(account_name, ips, name, resource_group, streaming_protocol, access_token=None, alternative_media_id=None, auto_start=None, client_access_policy=None, cross_domain_policy=None, description=None, encoding_type=None, hostname_prefix=None, key_frame_interval=None, key_frame_interval_duration=None, no_wait=None, preset_name=None, preview_ips=None, preview_locator=None, stream_options=None, streaming_policy_name=None, stretch_mode=None, tags=None, transcription_lang=None, use_static_hostname=None):
    '''
    Create a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - ips -- Space-separated IP addresses for access control. Allowed IP addresses can be specified as either a single IP address (e.g. "10.0.0.1") or as an IP range using an IP address and a CIDR subnet mask (e.g. "10.0.0.1/22"). Use "" to clear existing list. Use "AllowAll" to allow all IP addresses. Allowing all IPs is not recommended for production environments.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - streaming_protocol -- The streaming protocol for the live event. This value is specified at creation time and cannot be updated.

    Optional Parameters:
    - access_token -- A unique identifier for a stream. This can be specified at creation time but cannot be updated. If omitted, the service will generate a unique value.
    - alternative_media_id -- An Alternative Media Identifier associated with the StreamingLocator created for the preview. This value is specified at creation time and cannot be updated. The identifier can be used in the CustomLicenseAcquisitionUrlTemplate or the CustomKeyAcquisitionUrlTemplate of the StreamingPolicy specified in the StreamingPolicyName field.
    - auto_start -- The flag indicates if the resource should be automatically started on creation.
    - client_access_policy -- Filepath to the clientaccesspolicy.xml used by Microsoft Silverlight and Adobe Flash. Use @{file} to load from a file.
    - cross_domain_policy -- Filepath to the crossdomain.xml used by Microsoft Silverlight and Adobe Flash. Use @{file} to load from a file.
    - description -- The live event description.
    - encoding_type -- The encoding type for live event. This value is specified at creation time and cannot be updated. Allowed values: Premium1080p, None, Standard.
    - hostname_prefix -- When useStaticHostname is set to true, hostname_prefix specifies the first part of the hostname assigned to the live event preview and ingest endpoints. The final hostname would be a combination of this prefix, the media service account name and a short code for the Azure Media Services data center.
    - key_frame_interval -- Use an ISO 8601 time value between 0.5 to 20 seconds to specify the output fragment length for the video and audiotracks of an encoding live event. For example, use PT2S to indicate 2 seconds. For the video track it also defines the key frame interval, or the length of a GoP (group of pictures). If this value is not set for anencoding live event, the fragment duration defaults to 2 seconds. The value cannot be set for pass-through live events.
    - key_frame_interval_duration -- ISO 8601 timespan duration of the key frame interval duration in seconds. The value should be an interger in the range of 1 (PT1S or 00:00:01) to 30 (PT30S or 00:00:30) seconds.
    - no_wait -- Do not wait for the long-running operation to finish.
    - preset_name -- The encoding preset name. This value is specified at creation time and cannot be updated.
    - preview_ips -- Space-separated IP addresses for access control. Allowed IP addresses can be specified as either a single IP address (e.g. "10.0.0.1") or as an IP range using an IP address and a CIDR subnet mask (e.g. "10.0.0.1/22"). Use "" to clear existing list. Use "AllowAll" to allow all IP addresses. Allowing all IPs is not recommended for production environments.
    - preview_locator -- The identifier of the preview locator in Guid format. Specifying this at creation time allows the caller to know the preview locator url before the event is created. If omitted, the service will generate a random identifier. This value cannot be updated once the live event is created.
    - stream_options -- The options to use for the LiveEvent. This value is specified at creation time and cannot be updated.
    - streaming_policy_name -- The name of streaming policy used for the live event preview. This can be specified at creation time but cannot be updated.
    - stretch_mode -- Specifies how the input video will be resized to fit the desired output resolution(s). Default is None.  Allowed values: None, AutoSize, AutoFit.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - transcription_lang -- Live transcription language for the live event. Allowed values: ca-ES, da-DK, de-DE, en-AU, en-CA, en-GB, en-IN, en-NZ, en-US, es-ES, es-MX, fi-FI, fr-CA, fr-FR, it-IT, nl-NL, pt-BR, pt-PT, sv-SE See https://go.microsoft.com/fwlink/?linkid=2133742 for more information about the live transcription feature.
    - use_static_hostname -- Specifies whether a static hostname would be assigned to the live event preview and ingest endpoints. This value can only be updated if the live event is in Standby state. If hostname_prefix is not specified, the live event name will be used as the hostname prefix.
    '''
    return _call_az("az ams live-event create", locals())


def start(account_name, name, resource_group, no_wait=None):
    '''
    Start a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az ams live-event start", locals())


def standby(account_name, name, resource_group, no_wait=None):
    '''
    Allocate a live event to be started later.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az ams live-event standby", locals())


def stop(account_name, name, resource_group, no_wait=None, remove_outputs_on_stop=None):
    '''
    Stop a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove_outputs_on_stop -- Remove live outputs on stop.
    '''
    return _call_az("az ams live-event stop", locals())


def reset(account_name, name, resource_group, no_wait=None):
    '''
    Reset a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az ams live-event reset", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams live-event show", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams live-event delete", locals())


def list(account_name, resource_group):
    '''
    List all the live events of an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams live-event list", locals())


def update(account_name, name, resource_group, add=None, client_access_policy=None, cross_domain_policy=None, description=None, force_string=None, ips=None, key_frame_interval_duration=None, preview_ips=None, remove=None, set=None, tags=None):
    '''
    Update the details of a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - client_access_policy -- Filepath to the clientaccesspolicy.xml used by Microsoft Silverlight and Adobe Flash. Use @{file} to load from a file.
    - cross_domain_policy -- Filepath to the crossdomain.xml used by Microsoft Silverlight and Adobe Flash. Use @{file} to load from a file.
    - description -- The live event description.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ips -- Space-separated IP addresses for access control. Allowed IP addresses can be specified as either a single IP address (e.g. "10.0.0.1") or as an IP range using an IP address and a CIDR subnet mask (e.g. "10.0.0.1/22"). Use "" to clear existing list. Use "AllowAll" to allow all IP addresses. Allowing all IPs is not recommended for production environments.
    - key_frame_interval_duration -- ISO 8601 timespan duration of the key frame interval duration in seconds. The value should be an interger in the range of 1 (PT1S or 00:00:01) to 30 (PT30S or 00:00:30) seconds.
    - preview_ips -- Space-separated IP addresses for access control. Allowed IP addresses can be specified as either a single IP address (e.g. "10.0.0.1") or as an IP range using an IP address and a CIDR subnet mask (e.g. "10.0.0.1/22"). Use "" to clear existing list. Use "AllowAll" to allow all IP addresses. Allowing all IPs is not recommended for production environments.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az ams live-event update", locals())


def wait(account_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the live event is met.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az ams live-event wait", locals())




from ... pyaz_utils import _call_az

def list(account_name, resource_group):
    '''
    List the private link resources supported for Azure Cosmos DB.

    Required Parameters:
    - account_name -- Cosmosdb account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb private-link-resource list", locals())




from .... pyaz_utils import _call_az

def list(gateway_name, resource_group):
    '''
    List rules.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway rule list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a rule.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the request routing rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway rule show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a rule.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the request routing rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway rule delete", locals())


def create(gateway_name, name, resource_group, address_pool=None, http_listener=None, http_settings=None, no_wait=None, priority=None, redirect_config=None, rewrite_rule_set=None, rule_type=None, url_path_map=None):
    '''
    Create a rule.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the request routing rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - address_pool -- The name or ID of the backend address pool. If only one exists, omit to use as default.
    - http_listener -- The name or ID of the HTTP listener. If only one exists, omit to use as default.
    - http_settings -- The name or ID of the HTTP settings. If only one exists, omit to use as default.
    - no_wait -- Do not wait for the long-running operation to finish.
    - priority -- Priority of the request routing rule. Range from 1 to 2000
    - redirect_config -- The name or ID of the redirect configuration to use with the created rule.
    - rewrite_rule_set -- The name or ID of the rewrite rule set.
    - rule_type -- The rule type (Basic, PathBasedRouting).
    - url_path_map -- The name or ID of the URL path map.
    '''
    return _call_az("az network application-gateway rule create", locals())


def update(gateway_name, name, resource_group, add=None, address_pool=None, force_string=None, http_listener=None, http_settings=None, no_wait=None, priority=None, redirect_config=None, remove=None, rewrite_rule_set=None, rule_type=None, set=None, url_path_map=None):
    '''
    Update a rule.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the request routing rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - address_pool -- The name or ID of the backend address pool.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - http_listener -- The name or ID of the HTTP listener.
    - http_settings -- The name or ID of the backend HTTP settings.
    - no_wait -- Do not wait for the long-running operation to finish.
    - priority -- Priority of the request routing rule. Range from 1 to 2000
    - redirect_config -- The name or ID of the redirect configuration to use with the created rule.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - rewrite_rule_set -- The name or ID of the rewrite rule set.
    - rule_type -- The rule type (Basic, PathBasedRouting).
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - url_path_map -- The name or ID of the URL path map.
    '''
    return _call_az("az network application-gateway rule update", locals())




from ..... pyaz_utils import _call_az

def list(alias, name, namespace_name, resource_group):
    '''
    List the keys and connection strings of Authorization Rule for the Service Bus Namespace

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - name -- Name of Namespace AuthorizationRule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias authorization-rule keys list", locals())




'''
Manage policy events.
'''
from ... pyaz_utils import _call_az

def list(apply=None, filter=None, from_=None, management_group=None, namespace=None, order_by=None, parent=None, policy_assignment=None, policy_definition=None, policy_set_definition=None, resource=None, resource_group=None, resource_type=None, select=None, to=None, top=None):
    '''
    List policy events.

    Optional Parameters:
    - apply -- Apply expression for aggregations using OData notation.
    - filter -- Filter expression using OData notation.
    - from_ -- ISO 8601 formatted timestamp specifying the start time of the interval to query.
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - order_by -- Ordering expression using OData notation.
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - policy_assignment -- Name of policy assignment.
    - policy_definition -- Name of policy definition.
    - policy_set_definition -- Name of policy set definition.
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    - select -- Select expression using OData notation.
    - to -- ISO 8601 formatted timestamp specifying the end time of the interval to query.
    - top -- Maximum number of records to return.
    '''
    return _call_az("az policy event list", locals())




'''
Manage synapse kusto
'''
from ... pyaz_utils import _call_az
from . import attached_database_configuration, data_connection, database, database_principal_assignment, pool, pool_principal_assignment




from .... pyaz_utils import _call_az

def show(connection_name, resource_group):
    '''
    Retrieve a VPN connection shared key.

    Required Parameters:
    - connection_name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vpn-connection shared-key show", locals())


def reset(connection_name, key_length, resource_group=None):
    '''
    Reset a VPN connection shared key.

    Required Parameters:
    - connection_name -- Connection name.
    - key_length -- The virtual network connection reset shared key length, should between 1 and 128.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vpn-connection shared-key reset", locals())


def update(connection_name, resource_group, value, add=None, force_string=None, remove=None, set=None):
    '''
    Update a VPN connection shared key.

    Required Parameters:
    - connection_name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - value -- The virtual network connection shared key value.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network vpn-connection shared-key update", locals())




from .... pyaz_utils import _call_az

def list(instance_id, location, restore_location, restore_timestamp):
    '''
    List all the databases and its collections that can be restored in the given account at the given timesamp and region.

    Required Parameters:
    - instance_id -- InstanceId of the Account
    - location -- Azure Location of the account
    - restore_location -- The region of the restore.
    - restore_timestamp -- The timestamp of the restore
    '''
    return _call_az("az cosmosdb mongodb restorable-resource list", locals())

